@@ -33,7 +33,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr. 1997
- * $Id: chasen.c,v 1.17 2002/12/02 07:32:41 kazuma-t Exp $
+ * $Id: chasen.c,v 1.18 2003/06/04 14:19:35 kazuma-t Exp $
  *
  */
 
@@ -119,8 +119,7 @@ opt_form_usage(FILE * fp)
 	"  %?U/STR1/STR2/\n",
 	"          if unknown word, STR1, otherwise, STR2\n",
 	"  %U/STR/\n",
-	"          if unknown word, \"", JSTR_UNKNOWN_WORD1,
-	    "\", otherwise, STR\n",
+	"          if unknown word, \"UNKNOWN\", otherwise, STR\n",
 	"  %%      '%'\n",
 	"  .       specify the field width\n",
 	"  -       specify the field width\n",
@@ -171,6 +170,9 @@ usage(FILE * fp)
 	"    -F format      show morpheme with formatted output\n",
 	"    -Fh            print help of -F option\n",
 	"  (miscellaneous)\n",
+	"    -i schema      encoding schema.\n",
+        "                   e: EUC-JP, s: Shift_JIS, ",
+	"w: UTF-8, a: ISO-8859-1\n",
 	"    -j             Japanese sentence mode\n",
 	"    -o file        write output to `file'\n",
 	"    -w width       specify the cost width\n",
