@@ -2,7 +2,7 @@
  * chadic.h
  *     1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
  *
- * $Id: chadic.h,v 1.35 2003/01/08 12:12:24 kazuma-t Exp $
+ * $Id: chadic.h,v 1.37 2003/06/04 14:19:35 kazuma-t Exp $
  */
 
 #ifndef __CHADIC_H__
@@ -46,90 +46,6 @@
 #define TYPE_NUM		256
 #define FORM_NUM		128
 
-#define JSTR_BOS             "ʸƬ"
-#define ESTR_BOS             "BOS"
-#define JSTR_EOS             "ʸ"
-#define ESTR_EOS             "EOS"
-#define ESTR_BOS_EOS         "BOS/EOS"
-
-/* cforms.cha */
-#define JSTR_BASE_FORM_STR   "ܷ"
-#define ESTR_BASE_FORM_STR1  "BASEFORM"
-#define ESTR_BASE_FORM_STR2  "STEMFORM"
-#define JSTR_BASE_FORM       "ܷ"
-#define ESTR_BASE_FORM1      "BASEFORM"
-#define ESTR_BASE_FORM2      "STEMFORM"
-
-/* *.dic */
-#define JSTR_DEF_POS_COST  "ǥեʻ쥳"
-#define ESTR_DEF_POS_COST  "DEF_POS_COST"
-#define JSTR_MRPH          ""
-#define ESTR_MRPH          "MORPH"
-#define JSTR_POS           "ʻ"
-#define ESTR_POS           "POS"
-#define JSTR_WORD          "Ф"
-#define ESTR_WORD          "LEX"
-#define JSTR_READING       "ɤ"
-#define ESTR_READING       "READING"
-#define JSTR_BASE          ""
-#define ESTR_BASE          "BASE"
-#define JSTR_PRON          "ȯ"
-#define ESTR_PRON          "PRON"
-#define JSTR_CTYPE         "ѷ"
-#define ESTR_CTYPE         "CTYPE"
-#define JSTR_CFORM         "ѷ"
-#define ESTR_CFORM         "CFORM"
-#define JSTR_INFO1         "ղþ"
-#define JSTR_INFO2         "̣"
-#define ESTR_INFO          "INFO"
-#define JSTR_COMPOUND      "ʣ"
-#define ESTR_COMPOUND      "COMPOUND"
-#define JSTR_SEG           ""
-#define ESTR_SEG           "SEG"
-#define JSTR_CONN_ATTR     "Ϣ°"
-
-/* chasenrc */
-#define JSTR_GRAM_FILE      "ʸˡե"
-#define ESTR_GRAM_FILE      "GRAMMAR"
-#define JSTR_UNKNOWN_WORD1  "̤θ"
-#define JSTR_UNKNOWN_WORD2  "̤"
-#define ESTR_UNKNOWN_WORD   "UNKNOWN"
-#define JSTR_UNKNOWN_WORD   JSTR_UNKNOWN_WORD1
-#define JSTR_UNKNOWN_POS1   "̤θʻ"
-#define JSTR_UNKNOWN_POS2   "̤ʻ"
-#define ESTR_UNKNOWN_POS    "UNKNOWN_POS"
-#define JSTR_SPACE_POS      "ʻ"
-#define ESTR_SPACE_POS      "SPACE_POS"
-#define JSTR_ANNOTATION     ""
-#define ESTR_ANNOTATION     "ANNOTATION"
-#define JSTR_POS_COST       "ʻ쥳"
-#define ESTR_POS_COST       "POS_COST"
-#define JSTR_CONN_WEIGHT    "ϢܥȽŤ"
-#define ESTR_CONN_WEIGHT    "CONN_WEIGHT"
-#define JSTR_MRPH_WEIGHT    "ǥȽŤ"
-#define ESTR_MRPH_WEIGHT    "MORPH_WEIGHT"
-#define JSTR_COST_WIDTH     ""
-#define ESTR_COST_WIDTH     "COST_WIDTH"
-#define JSTR_DEF_CONN_COST  "̤Ϣܥ"
-#define ESTR_DEF_CONN_COST  "DEF_CONN_COST"
-#define JSTR_COMPOSIT_POS      "Ϣʻ"
-#define ESTR_COMPOSIT_POS      "COMPOSIT_POS"
-#define JSTR_OUTPUT_COMPOUND   "ʣ"
-#define ESTR_OUTPUT_COMPOUND   "OUTPUT_COMPOUND"
-#define ESTR_PAT_FILE       "PATDIC" /* changed by Tatuo 960920 */
-#define ESTR_SUF_FILE       "SUFDIC"
-#define ESTR_DA_FILE       "DADIC"
-#define JSTR_OUTPUT_FORMAT  "ϥեޥå"
-#define ESTR_OUTPUT_FORMAT  "OUTPUT_FORMAT"
-#define JSTR_LANG           ""
-#define ESTR_LANG           "LANG"
-#define JSTR_DELIMITER      "ڤʸ"
-#define ESTR_DELIMITER      "DELIMITER"
-#define JSTR_BOS_STR        "BOSʸ"
-#define ESTR_BOS_STR        "BOS_STRING"
-#define JSTR_EOS_STR        "EOSʸ"
-#define ESTR_EOS_STR        "EOS_STRING"
-
 #define VCHA_CONNECT_FILE "connect.cha"
 #define VCHA_CONNTMP_FILE "_connect.cha"
 #define VCHA_GRAMMAR_FILE "grammar.cha"
@@ -170,9 +86,6 @@
 /* added by S.Kurohashi for mrph weight default values */
 #define MRPH_DEFAULT_WEIGHT	1
 
-#define strmatch2(s,s1,s2)      (!strcmp(s,s1)||!strcmp(s,s2))
-#define strmatch3(s,s1,s2,s3)   (!strcmp(s,s1)||!strcmp(s,s2)||!strcmp(s,s3))
-
 /*
  * structures
  */
@@ -202,10 +115,10 @@ typedef struct _cell {
 /* morpheme */
 typedef struct _mrph {
     char midasi[MIDASI_LEN];  /* surface form */
-    char yomi[MIDASI_LEN];    /* Japanese reading */
+    char yomi[MIDASI_LEN * 2];    /* Japanese reading *//* XXX ad hoc */
     char *info;               /* semantic information */
     char *base;               /* base form */
-    char pron[MIDASI_LEN];    /* Japanese pronunciation */
+    char pron[MIDASI_LEN * 2];    /* Japanese pronunciation *//* XXX ad hoc */
     unsigned short hinsi;     /* POS number */
     unsigned char ktype;      /* Conjugation type number */
     unsigned char kform;      /* Conjugation form number */
@@ -339,11 +252,6 @@ int cha_get_nhinsi_id(chasen_cell_t*);
 int cha_get_type_id(char*);
 int cha_get_form_id(char*, int);
 
-/* zentohan.c */
-unsigned char *euc2sjis(char*);
-unsigned char *sjis2euc(unsigned char*);
-unsigned char *hankana2zenkana(unsigned char*);
-
 /* getopt.c */
 int cha_getopt(char**, char*, FILE*);
 int cha_getopt_chasen(char**, FILE*);
