@@ -33,12 +33,11 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
- * $Id: chalib.c,v 1.40 2003/02/13 16:15:59 kazuma-t Exp $
+ * $Id: chalib.c,v 1.42 2003/06/04 14:19:35 kazuma-t Exp $
  */
 
 #include "chalib.h"
-#include "pat.h"
-#include "sufary.h"
+#include "literal.h"
 #include "tokenizer.h"
 
 #define CHA_NAME       "ChaSen"
@@ -53,8 +52,6 @@ enum cha_encode Cha_encode = CHASEN_ENCODE_EUCJP;
 
 static int cost_width0;
 
-static char patdic_filename[PAT_DIC_NUM][CHA_FILENAME_LEN];
-static char sufdic_filename[PAT_DIC_NUM][CHA_FILENAME_LEN];
 static char dadic_filename[PAT_DIC_NUM][CHA_FILENAME_LEN];
 
 static int opt_show = 'b', opt_form = 'f', opt_ja, opt_cmd;
@@ -174,12 +171,16 @@ chasen_getopt_argv(char **argv, FILE * fp)
 {
     int c;
 
+    cha_set_encode("");
     /*
      * read -r option 
      */
     Cha_optind = 0;
     while ((c = cha_getopt_chasen(argv, fp)) != EOF) {
 	switch (c) {
+	case 'i':
+	    cha_set_encode(Cha_optarg);
+	    break;
 	case 'r':
 	    /*
 	     * chasenrc file 
@@ -440,68 +441,6 @@ set_dic_filename(char *filename, char *s)
 	sprintf(filename, "%s%s", cha_get_grammar_dir(), s);
 }
 
-/*
- * cha_read_patdic - read patricia dictionaries
- */
-void
-cha_read_patdic(chasen_cell_t * cell)
-{
-    int num;
-    char patname[CHA_FILENAME_LEN];
-    char textname[CHA_FILENAME_LEN];
-
-    /*
-     * return if already read 
-     */
-    if (patdic_filename[0][0])
-	return;
-
-    for (num = 0; !nullp(cell); num++, cell = cha_cdr(cell)) {
-	if (num >= PAT_DIC_NUM)
-	    cha_exit_file(1, "too many patricia dictionary files");
-	set_dic_filename(patdic_filename[num], cha_s_atom(cha_car(cell)));
-
-	/*
-	 * open patdic 
-	 */
-	sprintf(textname, "%s.int", patdic_filename[num]);
-	sprintf(patname, "%s.pat", patdic_filename[num]);
-	Pat_dicfile[num] = pat_open(textname, patname);
-    }
-    Pat_ndicfile = num;
-}
-
-/*
- * cha_read_sufdic - read SUFARY dictionaries
- */
-void
-cha_read_sufdic(chasen_cell_t * cell)
-{
-    int num;
-    char filename[CHA_FILENAME_LEN];
-    char ary_filename[CHA_FILENAME_LEN];
-
-    /*
-     * return if already read 
-     */
-    if (sufdic_filename[0][0])
-	return;
-
-    for (num = 0; !nullp(cell); num++, cell = cha_cdr(cell)) {
-	if (num >= PAT_DIC_NUM)
-	    cha_exit_file(1, "too many SUFARY dictionary files");
-	set_dic_filename(sufdic_filename[num], cha_s_atom(cha_car(cell)));
-
-	/*
-	 * open sufdic 
-	 */
-	sprintf(filename, "%s.int", sufdic_filename[num]);
-	sprintf(ary_filename, "%s.ary", sufdic_filename[num]);
-	Suf_dicfile[num] = sa_openfiles(filename, ary_filename);
-    }
-    Suf_ndicfile = num;
-}
-
 void
 cha_read_dadic(chasen_cell_t * cell)
 {
