@@ -1,5 +1,5 @@
 /*
- * $Id: chalib.h,v 1.38 2003/02/14 07:41:34 kazuma-t Exp $
+ * $Id: chalib.h,v 1.39 2003/02/25 02:07:04 kazuma-t Exp $
  */
 
 #ifndef __CHALIB_H__
@@ -88,14 +88,8 @@ extern char *Cha_eos_string;
 extern int Cha_output_iscompound;
 
 /* dictionaries(dic.c) */
-#include "pat.h"
-#include "sufary.h"
 #include "dartsdic.h"
-extern SUFARY *Suf_dicfile[];
-extern pat_t *Pat_dicfile[];
 extern darts_t *Da_dicfile[];
-extern int Suf_ndicfile;
-extern int Pat_ndicfile;
 extern int Da_ndicfile;
 
 /*
