@@ -33,16 +33,12 @@
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
- * $Id: dic.c,v 1.10 2002/11/28 07:51:51 kazuma-t Exp $
+ * $Id: dic.c,v 1.11 2003/02/25 02:07:04 kazuma-t Exp $
  */
 #include "chalib.h"
 #include "dartsdic.h"
 
-SUFARY *Suf_dicfile[PAT_DIC_NUM];	/* dictionary (SUFDIC) */
-pat_t *Pat_dicfile[PAT_DIC_NUM];	/* dictionary (PATDIC) */
 darts_t *Da_dicfile[PAT_DIC_NUM];	/* dictionary (DARTSDIC) */
-int Suf_ndicfile = 0;
-int Pat_ndicfile = 0;
 int Da_ndicfile = 0;
 
 void
