@@ -37,11 +37,12 @@
  * 1990/12/14/Fri       Yutaka MYOKI(Nagao Lab., KUEE)
  * 1990/12/25/Tue       Modified
  * Oct. 1996       A.Kitauchi <akira-k@is.aist-nara.ac.jp>
- * $Id: iotool.c,v 1.14 2002/06/18 02:33:40 kazuma-t Exp $
+ * $Id: iotool.c,v 1.15 2003/06/04 14:19:35 kazuma-t Exp $
  */
 #include <stdio.h>
 #include <stdarg.h>
 #include "chadic.h"
+#include "literal.h"
 #include "config.h"
 
 #ifdef PATHTYPE_MSDOS
@@ -562,7 +563,7 @@ cha_read_grammar_dir(void)
 	char *s;
 	cell = cha_s_read(fp);
 	s = cha_s_atom(cha_car(cell));
-	if (strmatch2(s, JSTR_GRAM_FILE, ESTR_GRAM_FILE)) {
+	if (cha_litmatch(s, 1, STR_GRAM_FILE)) {
 	    strcpy(grammar_dir, cha_s_atom(cha_car(cha_cdr(cell))));
 	    s = grammar_dir + strlen(grammar_dir);
 	    if (s[-1] != PATH_DELIMITER) {
