@@ -35,10 +35,11 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
  * 1990/12/17/Mon       Yutaka MYOKI(Nagao Lab., KUEE)
- * $Id: katuyou.c,v 1.12 2003/02/13 16:15:59 kazuma-t Exp $
+ * $Id: katuyou.c,v 1.13 2003/06/04 14:19:35 kazuma-t Exp $
  */
 
 #include "chadic.h"
+#include "literal.h"
 
 ktype_t Cha_type[TYPE_NUM];
 kform_t Cha_form[TYPE_NUM][FORM_NUM];
@@ -61,8 +62,8 @@ read_type_form(FILE * fp)
 	cell1 = cha_car(cha_cdr(cell1));
 
 	/* base form string */
-	if (strmatch3(Cha_type[i].name, JSTR_BASE_FORM_STR,
-		      ESTR_BASE_FORM_STR1, ESTR_BASE_FORM_STR2)) {
+	if (cha_litmatch(Cha_type[i].name, 2,
+			 STR_BASE_FORM_STR1, STR_BASE_FORM_STR2)) {
 	    Cha_base_form_str = cha_strdup(cha_s_atom(cell1));
 	    i--;
 	    continue;
@@ -77,8 +78,8 @@ read_type_form(FILE * fp)
 	    if (!Cha_type[i].basic &&
 		(Cha_base_form_str
 		 ? !strcmp(Cha_form[i][j].name, Cha_base_form_str)
-		 : strmatch3(Cha_form[i][j].name, JSTR_BASE_FORM,
-			     ESTR_BASE_FORM1, ESTR_BASE_FORM2)))
+		 : cha_litmatch(Cha_form[i][j].name, 2,
+				STR_BASE_FORM1, STR_BASE_FORM2)))
 		Cha_type[i].basic = j;
 	    /*
 	     * gobi 
