@@ -37,10 +37,11 @@
  * Author: 1990/11/12/Mon Yutaka MYOKI(Nagao Lab., KUEE)
  *         1990/12/16/Mon Modified special thanks to Itsuki NODA
  *         A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr. 1997
- * $Id: lisp.c,v 1.10 2003/02/13 14:17:28 kazuma-t Exp $
+ * $Id: lisp.c,v 1.13 2003/06/10 07:29:45 kazuma-t Exp $
  */
 
 #include "chadic.h"
+#include "literal.h"
 
 #define COMMENTCHAR	';'
 #define COMMENTCHAR2	'#'
@@ -167,12 +168,13 @@ malloc_free_cell(int isfree)
     }
 }
 
+#define CHUNK_SIZE 512
 #define CHA_MALLOC_SIZE (1024 * 64)
 #define free_char()  malloc_char(-1)
 static void *
 malloc_char(int size)
 {
-    static char *ptr[256];
+    static char *ptr[CHUNK_SIZE];
     static int ptr_num = 0;
     static int idx = CHA_MALLOC_SIZE;
 
@@ -188,7 +190,7 @@ malloc_char(int size)
 	return NULL;
     } else {
 	if (idx + size >= CHA_MALLOC_SIZE) {
-	    if (ptr_num == 256)
+	    if (ptr_num == CHUNK_SIZE)
 		cha_exit(1, "Can't allocate memory");
 	    ptr[ptr_num++] = cha_malloc(CHA_MALLOC_SIZE);
 	    idx = 0;
@@ -375,9 +377,16 @@ myscanf(FILE * fp, char *str)
 	}
 
 	if (code != '\\' || in_quote == '\'') {
-	    *s++ = code;
-	    if (code & 0x80)
-		*s++ = fgetc(fp);
+	    switch (Cha_encode) { /* XXX */
+	    case CHASEN_ENCODE_SJIS:
+		*s++ = code;
+		if (code & 0x80)
+		    *s++ = fgetc(fp);
+		break;
+	    default:
+		*s++ = code;
+		break;
+	    }
 	} else {
 	    if ((code = fgetc(fp)) == EOF)
 		return 0;
