@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: mmap.c,v 1.11 2003/01/08 11:26:21 kazuma-t Exp $
+ * $Id: mmap.c,v 1.12 2003/04/19 14:34:39 kazuma-t Exp $
  */
 
 #include "config.h"
@@ -63,7 +63,7 @@
 #include <sys/mman.h>
 #endif
 
-#if !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H
+#if !defined HAVE_MMAP && defined HAVE_WINDOWS_H
 #include <windows.h>
 #endif
 
@@ -72,8 +72,8 @@
 #endif
 
 #ifndef HAVE_MMAP
-#define PROT_WRITE  0
-#define PROT_READ   0
+#define PROT_WRITE  2
+#define PROT_READ   1
 #endif
 
 #include "chalib.h"
@@ -81,7 +81,7 @@
 struct _cha_mmap_t {
     void *map;
     off_t size;
-#if !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H
+#if !defined HAVE_MMAP && defined HAVE_WINDOWS_H
     HANDLE hfile;
     HANDLE hmap;
 #endif
@@ -91,7 +91,7 @@ static cha_mmap_t *
 mmap_file(char *filename, int prot)
 {
     cha_mmap_t *mm;
-#if !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H
+#if !defined HAVE_MMAP && defined HAVE_WINDOWS_H
     unsigned long file_mode, map_mode, view_mode;
 #else
     int fd;
@@ -101,11 +101,11 @@ mmap_file(char *filename, int prot)
 
     mm = cha_malloc(sizeof(cha_mmap_t));
 
-#if !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H
+#if !defined HAVE_MMAP && defined HAVE_WINDOWS_H
     if ((prot & PROT_WRITE) != 0) {
 	file_mode = GENERIC_READ | GENERIC_WRITE;
 	map_mode = PAGE_READWRITE;
-	view_mode = FILE_MAP_ALL_ACCESS;
+	view_mode = FILE_MAP_WRITE;
     } else {
 	file_mode = GENERIC_READ;
 	map_mode = PAGE_READONLY;
@@ -132,7 +132,7 @@ mmap_file(char *filename, int prot)
 	cha_exit_perror(filename);
     }
 
-#else /* !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H */
+#else /* !defined HAVE_MMAP && defined HAVE_WINDOWS_H */
     if ((prot & PROT_WRITE) != 0)
 	flag = O_RDWR;
 	
@@ -153,7 +153,7 @@ mmap_file(char *filename, int prot)
 #endif /* HAVE_MMAP */
     close(fd);
 
-#endif /* HAVE_MMAP_H && defined HAVE_WINDOWS_H */
+#endif /* HAVE_MMAP && defined HAVE_WINDOWS_H */
     return mm;
 }
 
@@ -172,17 +172,17 @@ cha_mmap_file_w(char *filename)
 void
 cha_munmap_file(cha_mmap_t *mm)
 {
-#if !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H
+#if !defined HAVE_MMAP && defined HAVE_WINDOWS_H
     UnmapViewOfFile(mm->map);
     CloseHandle(mm->hmap);
     CloseHandle(mm->hfile);
-#else /* !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H */
+#else /* !defined HAVE_MMAP && defined HAVE_WINDOWS_H */
 #ifdef HAVE_MMAP
     munmap(mm->map, mm->size);
 #else /* HAVE_MMAP */
     cha_free(mm->map);
 #endif /* HAVE_MMAP */
-#endif /* !defined HAVE_MMAP_H && defined HAVE_WINDOWS_H */
+#endif /* !defined HAVE_MMAP && defined HAVE_WINDOWS_H */
     cha_free(mm);
 }
 
