@@ -37,15 +37,15 @@
  *
  *  modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
  *           by O.Imaichi <osamu-im@is.aist-nara.ac.jp>, Sep. 1996
- * $Id: print.c,v 1.35 2003/02/14 07:41:34 kazuma-t Exp $
+ * $Id: print.c,v 1.40 2003/06/10 07:27:37 kazuma-t Exp $
  */
 
 #include <stdarg.h>
 #include <stdio.h>
 #include <ctype.h>
 #include "chalib.h"
+#include "literal.h"
 #include "tokenizer.h"
-#include "pat.h"
 
 #define nth_mrph(n) ((mrph2_t*)cha_block_get_item(Cha_mrph_block,(n)))
 
@@ -252,10 +252,15 @@ static int
 comm_prefix_len(char *s1, char *s2)
 {
     char *s0 = s1;
-    for (; *s1 && *s1 == *s2; s1++, s2++) {
-	if ((unsigned char) *s1 & 0x80)
-	    if (*++s1 != *++s2)
-		break;
+    int len, i;
+
+    while (*s1) {
+	len = cha_tok_mblen(Cha_tokenizer, s1, 4 /* XXX */);
+	for (i = 0; i < len; i++)
+	    if (s1[i] != s2[i])
+		return s1 - s0;
+	s1 += len;
+	s2 += len;
     }
     return s1 - s0;
 }
@@ -274,7 +279,7 @@ set_ruby(char *dest, char *midasi, char *yomi,
     int plen, maxplen = 0;
 
     for (;;) {
-	for (; *y; y += ((unsigned char) *y & 0x80) ? 2 : 1) {
+	for (; *y; y += cha_tok_mblen(Cha_tokenizer, y, 4 /* XXX */)) {
 	    if (stat == 0) {
 		stat = 1;
 		if ((plen = comm_prefix_len(m, y)) > 0) {
@@ -287,7 +292,7 @@ set_ruby(char *dest, char *midasi, char *yomi,
 		y0 = y;
 		if (!*m || !*y)
 		    goto end_ruby;
-		m += ((unsigned char) *m & 0x80) ? 2 : 1;
+		m += cha_tok_mblen(Cha_tokenizer, m, 4 /* XXX */);
 		plen = maxplen = 0;
 		continue;
 	    }
@@ -298,7 +303,7 @@ set_ruby(char *dest, char *midasi, char *yomi,
 	}
 	if (maxplen == 0) {
 	    if (*m)
-		m += ((unsigned char) *m & 0x80) ? 2 : 1;
+		m += cha_tok_mblen(Cha_tokenizer, m, 4 /* XXX */);
 	    if (!*m)
 		ymax = y;
 	}
@@ -524,10 +529,10 @@ print_anno(int path_num, char *format)
     path->start = start;
 }
 
-/* XXX: this code is valid only with EUC-JP and Shift-JIS */
 #define copy_mbstr(d,s) \
-do { *(d)++ = *(s); \
-    if ((unsigned char)(*(s)) & 0x80 && *++(s)) *(d)++ = *(s); \
+do { int len = cha_tok_mblen(Cha_tokenizer, (s), 4 /* XXX */); \
+    while (len-- && *(s)) { *(d)++ = *(s)++; } \
+    s--; /* XXX */\
 } while (0)
 
 static void
@@ -648,7 +653,7 @@ cha_printf_mrph(int path_num, mrph2_t * mrph, char *format)
 		deli_left = '\0';
 		s--;
 		word = (Cha_lang == CHASEN_LANG_EN) ?
-		    ESTR_UNKNOWN_WORD : JSTR_UNKNOWN_WORD;
+		    CHA_LITE(STR_UNKNOWN_WORD) : CHA_LIT(STR_UNKNOWN_WORD);
 	    } else {
 		state = 2;
 		deli_right = get_deli_right(deli_left = *++s);
@@ -788,7 +793,7 @@ cha_printf_mrph(int path_num, mrph2_t * mrph, char *format)
 		cha_putc(*s, cha_output);
 	    else if (*++s == 'M' && mrph->is_undef)
 		word = (Cha_lang == CHASEN_LANG_EN) ?
-		    ESTR_UNKNOWN_WORD : JSTR_UNKNOWN_WORD;
+		    CHA_LITE(STR_UNKNOWN_WORD) : CHA_LIT(STR_UNKNOWN_WORD);
 	    /*
 	     * زʻʤֲγؤʻ̾ɽ 
 	     * when the POS has subdivision level,
@@ -1095,6 +1100,7 @@ print_best_path(int opt_form, char *format)
     composit_mrph.yomi = yomi;
     composit_mrph.pron = pron;
     composit_mrph.base = base;
+    composit_mrph.compound = NULL;
     cur_mrph = nth_mrph(Cha_path[path_buffer[pbuf_last - 1]].mrph_p);
 
     /* 
